@@ -10,13 +10,11 @@ mod stats;
 
 use self::stats::NetworkStats;
 use crate::routing::{
-    dkg::{verify_sig, KeyedSig, SectionAuthUtils},
-    peer::PeerUtils,
-    Error, Result, SectionAuthorityProviderUtils,
+    dkg::SectionAuthUtils, peer::PeerUtils, Error, Result, SectionAuthorityProviderUtils,
 };
 
 use crate::messaging::{
-    node::{Network, OtherSection, Peer, SectionAuth},
+    node::{Network, Peer, SectionAuth},
     SectionAuthorityProvider,
 };
 use crate::types::PrefixMap;
@@ -46,20 +44,13 @@ pub(super) trait NetworkUtils {
     /// TODO: return bool indicating whether anything changed.
     fn merge(&mut self, other: Network, section_chain: &SecuredLinkedList);
 
-    /// Update the info about a section.
-    ///
-    /// If this is for our sibling section, then `section_auth` is signed by them and so the signing
-    /// key is not in our `section_chain`. To prove the key is valid, it must be accompanied by an
-    /// additional `key_sig` which signs it using a key that is present in `section_chain`.
-    ///
-    /// If this is for a non-sibling section, then currently we require the info to be signed by our
-    /// section (so we need to accumulate the signature for it first) and so `key_sig` is not
-    /// needed in that case.
-    fn update_section(
+    /// Update our knowledge of a remote section's SAP only
+    /// if it's verifiable with the provided proof chain.
+    fn update_remote_section_sap(
         &mut self,
-        section_auth: SectionAuth<SectionAuthorityProvider>,
-        key_sig: Option<KeyedSig>,
-        section_chain: &SecuredLinkedList,
+        signed_section_auth: SectionAuth<SectionAuthorityProvider>,
+        proof_chain: &SecuredLinkedList,
+        our_section_chain: &SecuredLinkedList,
     ) -> bool;
 
     /// Returns the known section keys.
@@ -98,14 +89,14 @@ impl NetworkUtils for Network {
 
     /// Returns iterator over all known sections.
     fn all(&self) -> Box<dyn Iterator<Item = &SectionAuthorityProvider> + '_> {
-        Box::new(self.sections.iter().map(|info| &info.section_auth.value))
+        Box::new(self.sections.iter().map(|section_auth| &section_auth.value))
     }
 
     /// Get `SectionAuthorityProvider` of a known section with the given prefix.
     fn get(&self, prefix: &Prefix) -> Option<&SectionAuthorityProvider> {
         self.sections
             .get(prefix)
-            .map(|info| &info.section_auth.value)
+            .map(|section_auth| &section_auth.value)
     }
 
     /// Returns all elders from all known sections.
@@ -117,7 +108,6 @@ impl NetworkUtils for Network {
     fn get_elder(&self, name: &XorName) -> Option<Peer> {
         self.sections
             .get_matching(name)?
-            .section_auth
             .value
             .get_addr(name)
             .map(|addr| {
@@ -140,66 +130,107 @@ impl NetworkUtils for Network {
         }
     }
 
-    /// Update the info about a section.
-    ///
-    /// If this is for our sibling section, then `section_auth` is signed by them and so the signing
-    /// key is not in our `section_chain`. To prove the key is valid, it must be accompanied by an
-    /// additional `key_sig` which signs it using a key that is present in `section_chain`.
-    ///
-    /// If this is for a non-sibling section, then currently we require the info to be signed by our
-    /// section (so we need to accumulate the signature for it first) and so `key_sig` is not
-    /// needed in that case.
-    fn update_section(
+    /// Update our knowledge of a remote section's SAP only
+    /// if it's verifiable with the provided proof chain.
+    fn update_remote_section_sap(
         &mut self,
-        section_auth: SectionAuth<SectionAuthorityProvider>,
-        key_sig: Option<KeyedSig>,
-        section_chain: &SecuredLinkedList,
+        signed_section_auth: SectionAuth<SectionAuthorityProvider>,
+        proof_chain: &SecuredLinkedList,
+        our_section_chain: &SecuredLinkedList,
     ) -> bool {
-        let info = OtherSection {
-            section_auth: section_auth.clone(),
-            key_sig,
-        };
-
-        // With the change of AE, the voting of OtherSection is removed, which means the info of
-        // remote section is no longer being signed by own section.
-        // As this passed in section_chain is just our own chain during sync, which in a high chance
-        // won't contain the section_key of a remote section.
-        // So the handling logic is now changed to:
-        //     1, if section_chain validates, update as it is
-        //     2, if chain not validate but the if is self-validated and we don't have such entry,
-        //        we take that entry in.
-        // In case the entry turned out to be an outdated one, it will got updated via AE flow.
-        //
-        // Note this is just a temp resolvement. It's still being discussed whether shall bring back
-        // the re-vote to improve the security.
-
-        if !info.verify(section_chain)
-            && (!info.self_verify() || self.sections.get(&section_auth.value.prefix).is_some())
-        {
-            trace!(
-                "Failed to update remove section knowledge {:?}",
-                section_auth.value
+        // Check if SAP signature is valid
+        if !signed_section_auth.self_verify() {
+            warn!(
+                "Anti-Entropy: Failed to update remote section knowledge, SAP signature invalid: {:?}",
+                signed_section_auth.value
             );
             return false;
         }
 
-        if let Some(old) = self.sections.insert(info) {
-            if old.section_auth == section_auth {
+        // Make sure the proof chain can be trusted,
+        // i.e. check each key is signed by its parent/predecesor key.
+        if !proof_chain.self_verify() {
+            warn!(
+                "Anti-Entropy: Failed to update remote section knowledge, proof chain contains invalid signatures: {:?}",
+                proof_chain
+            );
+            return false;
+        }
+
+        /*
+        // Check the SAP's key is the last key of the proof chain
+        //
+        // FIXME: this verification currently breaks DKG flow, specifically when we receive
+        // a Proposal::OurElders we rely on updating the SAP of a remote section.
+        // We are keeping this verification disabled for the moment until Anti-Entropy
+        // is fully implemented, aty which point this verification shall be re-enabled.
+        if proof_chain.last_key() != &signed_section_auth.value.public_key_set.public_key() {
+            warn!(
+                "Anti-Entropy: Failed to update remote section knowledge, SAP's key ({:?}) doesn't match proof chain last key ({:?})",
+                 signed_section_auth.value.public_key_set.public_key(), proof_chain.last_key()
+            );
+            return false;
+        }
+        */
+
+        // We currently don't keep the complete chain of remote sections,
+        // **but** the SAPs of remote sections we keep were already verified by us
+        // as trusted before we store them in our local records.
+        // Thus, we just need to check our knowledge of the remote section's key
+        // is part of the proof chain received.
+        let prefix = signed_section_auth.value.prefix;
+        match self.sections.get(&prefix) {
+            Some(sap) if sap == &signed_section_auth => {
+                // It's the same SAP we are already aware of
+                warn!(
+                    "Anti-Entropy: Skip update remote section knowledge, SAP received is the same as the one we already are aware of: {:?}",
+                    signed_section_auth.value
+                );
                 return false;
             }
+            Some(sap) => {
+                // We are then aware of the prefix, let's just verify the new SAP can
+                // be trusted based on the SAP we aware of and the proof chain provided.
+                if !proof_chain.has_key(&sap.value.public_key_set.public_key()) {
+                    warn!(
+                        "Anti-Entropy: Failed to update remote section knowledge, SAP cannot be trusted: {:?}",
+                        signed_section_auth.value
+                    );
+                    return false;
+                }
+            }
+            None => {
+                // We are not aware of the prefix, let's then verify it can be
+                // trusted based on our own section chain and the provided proof chain.
+                if !proof_chain.check_trust(our_section_chain.keys()) {
+                    warn!(
+                        "Anti-Entropy: Failed to update remote section knowledge, cannot trust proof chain received for SAP: {:?}",
+                        signed_section_auth.value
+                    );
+                    return false;
+                }
+            }
         }
 
+        // We can now update our knowledge of the remote section's SAP.
+        // Note: we don't expect the same SAP to be found in our records
+        // for the prefix since we've already checked that above.
+        let _ = self.sections.insert(signed_section_auth);
+        info!(
+            "Anti-Entropy: Remote section knowledge updated: {:?}",
+            prefix
+        );
+
         true
     }
 
     /// Returns the known section keys.
     fn keys(&self) -> Box<dyn Iterator<Item = (Prefix, bls::PublicKey)> + '_> {
-        Box::new(self.sections.iter().map(|entry| {
-            (
-                entry.section_auth.value.prefix,
-                entry.section_auth.value.section_key(),
-            )
-        }))
+        Box::new(
+            self.sections
+                .iter()
+                .map(|section_auth| (section_auth.value.prefix, section_auth.value.section_key())),
+        )
     }
 
     /// Returns the latest known key for the prefix that matches `name`.
@@ -207,7 +238,7 @@ impl NetworkUtils for Network {
         self.sections
             .get_matching(name)
             .ok_or(Error::NoMatchingSection)
-            .map(|entry| entry.section_auth.value.section_key())
+            .map(|section_auth| section_auth.value.section_key())
     }
 
     /// Returns the latest known key for a section with `prefix`.
@@ -215,7 +246,7 @@ impl NetworkUtils for Network {
     fn key_by_prefix(&self, prefix: &Prefix) -> Option<bls::PublicKey> {
         self.sections
             .get_equal_or_ancestor(prefix)
-            .map(|entry| entry.section_auth.value.section_key())
+            .map(|section_auth| section_auth.value.section_key())
     }
 
     /// Returns the section_auth and the latest known key for the prefix that matches `name`,
@@ -224,7 +255,7 @@ impl NetworkUtils for Network {
         self.sections
             .get_matching(name)
             .ok_or(Error::NoMatchingSection)
-            .map(|value| value.section_auth.value.clone())
+            .map(|section_auth| section_auth.value.clone())
     }
 
     /// Returns network statistics.
@@ -247,7 +278,7 @@ impl NetworkUtils for Network {
         let known_prefixes = iter::once(&our.prefix).chain(
             self.sections
                 .iter()
-                .map(|info| &info.section_auth.value.prefix),
+                .map(|section_auth| &section_auth.value.prefix),
         );
         let is_exact = Prefix::default().is_covered_by(known_prefixes.clone());
 
@@ -264,47 +295,39 @@ impl NetworkUtils for Network {
     }
 }
 
-pub(super) trait OtherSectionUtils {
-    fn verify(&self, section_chain: &SecuredLinkedList) -> bool;
-
-    fn self_verify(&self) -> bool;
-}
-
-impl OtherSectionUtils for OtherSection {
-    fn verify(&self, section_chain: &SecuredLinkedList) -> bool {
-        if let Some(key_sig) = &self.key_sig {
-            section_chain.has_key(&key_sig.public_key)
-                && verify_sig(key_sig, &self.section_auth.sig.public_key)
-                && self.section_auth.self_verify()
-        } else {
-            self.section_auth.verify(section_chain)
-        }
-    }
-
-    fn self_verify(&self) -> bool {
-        self.section_auth.self_verify()
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
     use crate::routing::{dkg, section};
+    use anyhow::{Context, Result};
     use rand::Rng;
 
     #[test]
     fn closest() -> Result<()> {
-        let sk = bls::SecretKey::random();
-        let chain = SecuredLinkedList::new(sk.public_key());
+        let genesis_sk = bls::SecretKey::random();
+        let genesis_pk = genesis_sk.public_key();
 
+        let chain = SecuredLinkedList::new(genesis_pk);
         let p01: Prefix = "01".parse().unwrap();
         let p10: Prefix = "10".parse().unwrap();
         let p11: Prefix = "11".parse().unwrap();
 
         // Create map containing sections (00), (01) and (10)
         let mut map = Network::new();
-        let _ = map.update_section(gen_section_auth(&sk, p01)?, None, &chain);
-        let _ = map.update_section(gen_section_auth(&sk, p10)?, None, &chain);
+
+        let mut chain01 = chain.clone();
+        let section_auth_01 = gen_section_auth(&bls::SecretKey::random(), p01)?;
+        let pk01 = section_auth_01.value.public_key_set.public_key();
+        let sig01 = bincode::serialize(&pk01).map(|bytes| genesis_sk.sign(&bytes))?;
+        chain01.insert(&genesis_pk, pk01, sig01)?;
+        let _ = map.update_remote_section_sap(section_auth_01, &chain01, &chain);
+
+        let mut chain10 = chain.clone();
+        let section_auth_10 = gen_section_auth(&bls::SecretKey::random(), p10)?;
+        let pk10 = section_auth_10.value.public_key_set.public_key();
+        let sig10 = bincode::serialize(&pk10).map(|bytes| genesis_sk.sign(&bytes))?;
+        chain10.insert(&genesis_pk, pk10, sig10)?;
+        let _ = map.update_remote_section_sap(section_auth_10, &chain10, &chain);
 
         let mut rng = rand::thread_rng();
         let n01 = p01.substituted_in(rng.gen());
@@ -323,6 +346,6 @@ mod tests {
         prefix: Prefix,
     ) -> Result<SectionAuth<SectionAuthorityProvider>> {
         let (section_auth, _, _) = section::test_utils::gen_section_authority_provider(prefix, 5);
-        dkg::test_utils::section_signed(sk, section_auth)
+        dkg::test_utils::section_signed(sk, section_auth).context("Failed to generate SAP")
     }
 }
